Fluffy & Moist Coconut Cake - Sally's Baking Addiction
Author: Sally
Description: This perfect coconut cake sets the bar for homemade cakes everywhere. It's supremely moist with a soft fluffy crumb and intense coconut flavor.
Date: 2019-04-05T04:00:38+00:00

Skip to content

# Fluffy & Moist Coconut Cake

Jump To Recipe
1,618 Comments
Author: Sally
Published: 04/05/2019Updated: 02/18/2022
This post may contain affiliate links. Read our disclosure policy.

This perfect coconut cake sets the bar for homemade cakes everywhere. It’s supremely moist with a soft fluffy crumb and intense coconut flavor. To ensure success, follow this recipe carefully including using cake flour, egg whites, sour cream, and canned coconut milk.

At the request of many readers, let me introduce you to the best coconut cake I’ve ever had. Homemade with love for coconut lovers everywhere, this cake exceeds my expectations. Complete with silky coconut cream cheese buttercream, she’s absolutely perfect and juxtaposes bold flavor with a light crumb.

I endlessly tested this cake recipe. In fact, I’m pretty sure my head turned into an actual coconut during the process. Is there shredded coconut caked into the crevices of my kitchen floor and backsplash? Yes.

## 5 Reasons to Love This Coconut Cake Recipe

1. Not Dry: This coconut cake is mega moist. There’s no point wasting your time (or calories!) on dry cakes.
2. Intensely Flavorful: Using coconut milk, shredded coconut, and coconut extract, you are guaranteed an intensely flavorful coconut cake.
3. Soft & Fluffy: By following the recipe carefully, as well as using the power ingredients described below, you are guaranteed a soft-as-silk coconut cake crumb.
4. Any Shape: Use this cake batter for coconut Bundt cake, coconut cupcakes, a 2-layer cake, 3-layer cake, or a coconut sheet cake.
5. Gets Along With Everyone: Use the frosting recipe below or try strawberry frosting, lemon frosting, brown butter cream cheese frosting, champagne frosting, or chocolate buttercream. Add raspberry cake filling between the layers or drizzle salted caramel on top! With so many ways to customize, this coconut cake is always a crowd-favorite when looking for Easter dessert ideas.

## Coconut Cake Video Tutorial

This recipe sets the bar for homemade cakes everywhere. It’s simply exquisite and is sure to be one of your favorite spring dessert recipes and Easter brunch recipes. Talk about a show stopper!

## How to Make Coconut Cake

I adapted this recipe from my favorite white cake. Its pristine crumb, fluffy texture, and stick-to-your-fork moisture guarantee cake success. In fact, I have the recipe memorized and even used it as the base of pistachio cake, cookies & cream cake, espresso cake, burnt sugar caramel cake, and strawberry cake. The recipe is cake gold and I knew it would be the perfect starting point for a fluffy and moist coconut cake.

Your coconut cake journey begins with two mixing bowls. Dry ingredients in one and wet ingredients in another (see full recipe instructions below). Combine the two in your mixer, along with coconut milk and sweetened shredded/flaked coconut. That’s it! Your coconut cake batter is ready to bake.

Creamed butter and sugar provide a solid base for this cake recipe. Use room temperature butter, and remember that room temperature is cooler than you think.

Another tip: Use all room temperature ingredients, including the eggs and sour cream. Why? Ingredients bond together very easily when they’re warmer, which creates an evenly textured baked good. Cold ingredients do not emulsify together. Period.

## Use These 6 Power Ingredients

Cake is literally nothing without its ingredients and these power players are the difference between dense dry cake and light moist cake.

1. Cake Flour: Cake flour produces the softest cake. If you don’t usually buy cake flour, make the exception here. It’s sold in the baking aisle with the other flours. You can use leftovers in any of these cake flour recipes. If you can’t find it, try making this cake flour substitute.
2. Egg Whites: Egg yolks are wonderful for moisture, but they’re heavy and weigh down cakes. We use whole eggs in my Easter coconut cake which is much more dense, like a pound cake. To keep this coconut cake light and fluffy, use only egg whites. We’ll add the moisture back in with sour cream.
3. Sour Cream: The moist maker! This cake melts in your mouth.
4. Coconut Extract: I tested this recipe with and without coconut extract. We loved it both ways, but coconut extract is necessary for best coconut flavor. It’s in the baking aisle near the vanilla extract.
5. Canned Coconut Milk: Canned coconut milk is a cooking ingredient, not a beverage. It’s creamier and thicker than regular milk and usually found near the Thai food products. Do not use the refrigerated coconut milk beverage that comes in a carton, because the two are very different.
6. Sweetened Shredded Coconut: I recommend using sweetened shredded coconut, also called sweetened flaked coconut. It’s moister than unsweetened coconut and that makes a big difference in the cake’s texture. I reduced the added sugar in the cake batter to make up for the sweetness. Sweetened coconut is sometimes sold as long skinny shreds, a size some find off-putting in cake. Therefore, I recommend pulsing them in a food processor so they’re smaller.

## Coconut Cream Cheese Buttercream Frosting

What do you love about vanilla buttercream? It’s buttery, sweet, and smooth.

And what about cream cheese frosting? It’s creamy, silky, and tangy.

Let’s combine the two, then add coconut milk and coconut extract. It’s even creamier and silkier than the coconut frosting on these coconut chocolate Easter cupcakes so that glides onto the cake seamlessly. (Which is a happy bonus because decorating a layer cake can be quite the task. See more below.)

If you prefer a non-cream cheese option, use my vanilla buttercream instead—use canned coconut milk instead of milk and add 1/2 teaspoon coconut extract.

## How to Frost a Layer Cake

Alright, let’s do this.

1. Cool cakes completely. Sounds obvious, but even the tiniest bit of warmth will melt the frosting. As a result, the layer cake will slip, slide, or even cave in!
2. If your cakes have a dome on top, level them off with a cake leveler or serrated knife. Flat-topped cakes ensure a straight and sturdy layer cake.
3. Choose a serving plate or cake stand. Here is the cake stand I use in these pictures!
4. Place the bottom layer on the cake stand. Using an icing spatula, spread 1 and 1/2 cups of frosting in an even layer on top. Bring the frosting just over the edge of the cake; this will be helpful when it’s time to frost the sides.
5. Place the second layer top-side-down on top. Make sure it aligns with the bottom cake layer.
6. Spread 1 and 1/2 cups frosting evenly on top, just as you did with the bottom layer.
7. Place third layer top-side-up on top. Again, make sure it’s perfectly aligned.
8. Divide the remaining frosting in half. (Just eyeball it.) Dollop half of the frosting on top of the cake and use an icing spatula to smooth it to the edges. Apply *some* of the remaining frosting all around the sides of the cake, then use a bench scraper to smooth it in a thin layer. Apply the rest of the frosting on the sides of the cake, then bench scrape to smooth it all out.
9. Wipe any excess frosting off of the cake stand.

You can watch me decorate this coconut cake in the video tutorial above. Don’t stress; if you take your time and make sure the cake layers are totally straight, you’re all set.

## But I Don’t Want to

Skip the drama and make a coconut sheet cake instead! Sheet cakes are easier to frost because they’re only one layer. See my recipe note about different size coconut cakes.

## What About the Buttercream Roses?

Let’s give my assistant, Stephanie, a round of applause. This was her first time making “3D” buttercream roses and look how beautifully they turned out! She made the buttercream roses at my house and I froze them until it was time to decorate the coconut cake. She followed this video tutorial. Keep in mind that the cream cheese buttercream WILL NOT work for the intricate buttercream roses. Instead, use my vanilla buttercream and add 1 extra cup of confectioners’ sugar. You need very stiff buttercream for these roses. You also need small squares of parchment paper and:

- Wilton Petal Tip 104
- Flower Nail
- Reusable Piping Bags or Disposable Piping Bags

Loosely cover the roses, then freeze or refrigerate them until ready to decorate, up to 1 week. No need to thaw prior to decorating the cake. Peel off parchment square and place the buttercream rose on the cake. If you’re traveling with the cake, I recommend securing the roses with a tiny dollop of cream cheese buttercream underneath.

Looking for something easier? Use Wilton 1M piping tip for these easy two-toned frosting buttercream roses.

## More Classic Cake Recipes

Flavor is the name, moist is the game. These are some of my favorite classic cake recipes!

- Pound Cake
- Vanilla Cake
- Carrot Cake
- Red Velvet Cake
- Strawberry Cake (made from real strawberries)
- Lemon Blueberry Cake
- Chocolate Cake

Print

## Coconut Cake

★★★★★ 4.9 from 534 reviews

- Author: Sally
- Prep Time: 35 minutes
- Cook Time: 22 minutes
- Total Time: 4 hours
- Yield: 12 servings
- Category: Dessert
- Method: Baking
- Cuisine: American

Print Recipe
Pin Recipe

### Description

This perfect coconut cake sets the bar for homemade cakes everywhere. It’s supremely moist with a soft fluffy crumb and intense coconut flavor. For success, follow this recipe carefully including using cake flour, egg whites, sour cream, and canned coconut milk.

### Ingredients

- 2 and 1/2 cups (285g) cake flour (spooned & leveled)
- 2 teaspoons baking powder
- 1/2 teaspoon baking soda
- 1 teaspoon salt
- 3/4 cup (12 Tbsp; 170g) unsalted butter, softened to room temperature
- 1 and 2/3 cups (330g) granulated sugar
- 5 large egg whites, at room temperature
- 1/2 cup (120g) sour cream, at room temperature
- 2 teaspoons pure vanilla extract
- 1 teaspoon coconut extract
- 1 cup (240ml) unsweetened canned coconut milk, at room temperature*
- 1 cup (80g) sweetened shredded coconut

#### Coconut Cream Cheese Buttercream

- 1 cup (16 Tbsp; 226g) unsalted butter, softened to room temperature
- 8 ounces (226g) full-fat brick cream cheese, softened to room temperature*
- 5 cups (600g) confectioners’ sugar
- 2 Tablespoons (30ml) canned coconut milk
- 1/2 teaspoon pure vanilla extract
- 1/2 teaspoon coconut extract
- 1/8 teaspoon salt
- 2 cups (160g) sweetened shredded coconut

Cook Mode Prevent your screen from going dark

### Instructions

1. Preheat oven to 350°F (177°C). Grease three 9-inch cake pans, line with parchment paper rounds, then grease the parchment paper. Parchment paper helps the cakes seamlessly release from the pans. (If it’s helpful, see this parchment paper rounds for cakes video & post.)
2. Make the cake: Whisk the cake flour, baking powder, baking soda, and salt together. Set aside.
3. Using a handheld or stand mixer fitted with a paddle or whisk attachment, beat the butter and sugar together on medium-high speed until smooth and creamy, about 2 minutes. Scrape down the sides and up the bottom of the bowl with a rubber spatula as needed. Beat in the egg whites until combined, then add the sour cream, vanilla extract, and coconut extract. Beat until combined. Mixture will look curdled as a result of the varying textures and solid butter combining. Scrape down the sides and up the bottom of the bowl as needed. With the mixer on low speed, slowly add the dry ingredients and coconut milk. Beat on low speed until combined, then add the shredded coconut. Whisk it all by hand to make sure there are no butter lumps at the bottom of the bowl. The batter will be slightly thick.
4. Pour batter evenly into cake pans. Weigh them to ensure accuracy, if desired. Bake for 21–23 minutes or until the cakes are baked through. To test for doneness, insert a toothpick into the center of the cake. If it comes out clean, it’s done. Allow cakes to cool completely in the pans set on a wire rack. The cakes must be completely cool before frosting and assembling.
5. Make the frosting: In a large bowl using a handheld or stand mixer fitted with a whisk or paddle attachment, beat the butter and cream cheese together on medium speed until creamy and smooth, about 2 minutes. Add confectioners’ sugar, coconut milk, vanilla extract, coconut extract, and salt with the mixer running on low. Increase to high speed and beat for 3 minutes. Add more confectioners’ sugar if frosting is too thin, more coconut milk if frosting is too thick, or an extra pinch of salt if frosting is too sweet.
6. Assemble and decorate: Using a large serrated knife, slice a thin layer off the tops of the cakes to create a flat surface. Discard (or crumble over ice cream!). Place 1 cake layer on your cake stand, cake turntable, or serving plate. Evenly cover the top with about 1 and 1/2 cups of frosting. Top with second cake layer and evenly cover the top with about 1 and 1/2 cups of frosting. Top with the third cake layer. Spread the remaining frosting all over the top and sides. I use and recommend an icing spatula to apply the frosting and a bench scraper to smooth the sides. Sprinkle coconut on top of the cake and apply it to the sides. This can get a little messy and you can watch me do it in the video tutorial. See blog post above about buttercream rose decoration.
7. Refrigerate cake for at least 20 minutes before slicing. This helps the cake hold its shape when cutting, though it’s still a pretty fluffy cake!
8. Cover leftover cake tightly and store in the refrigerator for up to 5 days.

### Notes

1. Make Ahead & Freezing Instructions: The cake layers can be baked, cooled, and covered tightly at room temperature overnight. Likewise, the frosting can be prepared, then covered and refrigerated overnight. When ready to decorate, let the frosting sit at room temperature to slightly soften for about 15 minutes, then give it one more mix with the mixer on medium speed for about 1 minute before frosting cake. Frosted cake or unfrosted cake layers can be frozen for up to 2–3 months. Thaw overnight in the refrigerator and bring to room temperature before decorating/serving.
2. Special Tools (affiliate links): 9-Inch Cake Pans | Electric Mixer (Handheld or Stand Mixer) | Glass Mixing Bowls | Whisk | Cake Stand or Cake Turntable | Icing Spatula | Bench Scraper | Cake Carrier (for storing)
3. Cake Flour: For the best results, I strongly recommend cake flour. You can find cake flour in the baking aisle and I have many more recipes using it. If you can’t find it, try making this cake flour substitute.
4. Egg Whites: Egg whites (no yolks) are KEY to the cake’s fluffy texture. For best success, I recommend using fresh eggs instead of carton egg whites. (Using an egg separator is really handy!) Here are all my recipes using leftover egg yolks. Success tip: Eggs separate much easier when they’re cold.
5. Canned Coconut Milk: Canned coconut milk is a cooking ingredient, not a beverage. It is usually unsweetened, so make sure you’re using unsweetened. It’s usually found in the grocery store near the Thai food products. Do not use refrigerated carton coconut milk beverage. You need 1 cup for the cake, not the entire can. You use 2 more Tablespoons in the frosting.
6. Sweetened Shredded Coconut: I recommend using sweetened shredded/flaked coconut. It’s moister than unsweetened coconut and that makes a big difference in the cake’s texture. If desired, pulse the coconut shreds in a food processor to chop them up so they aren’t as long inside and outside of the cake. Chopping the coconut is optional.
7. Cream Cheese: Use brick cream cheese, not cream cheese spread. If desired, you can use this vanilla buttercream instead (no cream cheese). Use canned coconut milk instead of milk and add 1/2 teaspoon coconut extract.
8. 9×13-Inch Sheet Cake: Simply pour the batter into a greased and lightly floured 9×13-inch pan and bake for 40 minutes or until a toothpick inserted in the center comes out clean.
9. 2-Layer Cake: Prepare two 9-inch cake pans in step 1. Divide batter between pans and bake for 24–26 minutes or until a toothpick inserted in the center comes out clean.
10. Bundt Cake: This cake batter will fit into a greased 10-cup or larger Bundt pan. I’m unsure of the exact bake time (likely around an hour); use a toothpick to test for doneness. Same oven temperature.
11. Cupcakes: Fill cupcake liners 2/3 full. Bake at 350°F (177°C) for 19–21 minutes. Yields about 2–3 dozen. Or try my vanilla cupcakes recipe and substitute canned coconut milk for whole milk, 1/2 teaspoon coconut extract for the vanilla bean, and add 3/4 cup (60g) of sweetened shredded coconut.
12. Why is everything at room temperature? All refrigerated items should be at room temperature so the batter mixes together easily and evenly. Read more about the importance of room temperature ingredients.

Keywords: cake, coconut cake, coconut

### Leave a Comment Cancel Reply

My team and I love hearing from you! Submit your question or recipe review here. Please see our FAQ page for many answers to common questions. Your email address will not be published.

Recipe rating ★ 5 Stars ☆ ★ 4 Stars ☆ ★ 3 Stars ☆ ★ 2 Stars ☆ ★ 1 Star ☆

Message

Author*

Email*

Δ

This site uses Akismet to reduce spam. Learn how your comment data is processed.

## Reader Comments & Reviews

1. Tatenda says:
   September 3, 2023

   Hello Sally and Team. I want to try out this cake , only problem is I don’t have sweetened coconut, I have mlbever seen it in our local shops in mycountryhere in Africa. I only see dessicated coconut. Will the work? How best do I do it? By the way your red velvet cake recipe is my go to recipe for red velvet cake.

   Reply
   - Michelle @ Sally's Baking Recipes says:
     September 3, 2023

     Hi Tatenda, you can use the desiccated coconut here with no other changes to the recipe!

     Reply
2. Dara says:
   September 1, 2023

   When I buy coconut milk, the fat usually is solidified on the top. Is it best to mix this in and then measure the coconut milk for the recipe?

   Reply
   - Michelle @ Sally's Baking Recipes says:
     September 2, 2023

     Hi Dara, you can shake the can before opening it to ensure it is mixed well.

     Reply
3. Mars says:
   September 1, 2023

   I cannot find sweetened coconut anywhere! What can I do to balance the flour if I can only use unsweetened coconut? Any tips would be greatly appreciated!

   Reply
   - Lexi @ Sally's Baking Recipes says:
     September 1, 2023

     Hi Mars, you can use unsweetened coconut flakes instead—the cake will still be plenty sweet! Do not add any more sugar.

     Reply
4. mel coxon says:
   August 29, 2023

   I have tried this recipe but never comes out correctly . When it comes out of the oven it collapses into a soggy stodgy lump. it is brown and when tested the middle is baked , what am I doing wrong ?

   Reply
   - Lexi @ Sally's Baking Recipes says:
     August 29, 2023

     Hi Mel, it sounds like the batter may be over mixed. Over mixing the batter is usually the culprit for squat, dense cakes. Be sure, too, that your baking powder and baking soda are fresh for optimal rise. We find they start to lose their strength after about 3 months, even if not technically expired. Hope this helps for next time!

     Reply
5. Zoe says:
   August 25, 2023

   I’m not sure if this has been answered, but how possible is it to scale this down? I’m mostly worried about the egg whites as everything else is more divisible. I made this a few years ago for a party and it was still SO MUCH CAKE. Thinking about it this year and the party is smaller. Thanks!

   Reply
   - Trina @ Sally's Baking Recipes says:
     August 25, 2023

     Hi Zoe! You could halve the recipe for one thicker 9 inch cake. An egg white usually weights about 30 grams, so you would need about 75 grams egg whites for a half batch. Or, our coconut cupcakes recipe makes the perfect amount of batter for a three layer 6 inch cake.

     Reply
     - Zoe says:
       August 25, 2023

       Thank you!

6. Joan Allison says:
   August 25, 2023

   Can you tell me if using toasted coconut would work in this recipie?

   Reply
   - Trina @ Sally's Baking Recipes says:
     August 25, 2023

     Hi Joan! You can definitely use toasted coconut for decorating the outside of the cake.

     Reply
7. Lily says:
   August 25, 2023

   I made this today and it tastes fantastic and the texture is absolutely perfect. I only had to switch to using 2 smaller pans, because those were the only ones I had two of in the same size and so I needed to adjust the baking time quite a bit. (After 30 minutes the centre was still very runny, so I think they ended up baking for almost 50 minutes.) But it still came out very nicely!
   I can definitely see me making this again sometime and I am wondering if you think it would be possible to cut the cakes in half horizontally or if they are too soft for that? Since my pans are smaller they come out rather high and I’d like the individual layers to be a little thinner next time.

   Reply
   - Trina @ Sally's Baking Recipes says:
     August 25, 2023

     Hi Lily, that depends on how thick your cake layers are and what size pan you used – you can certainly try slicing the layers if desired!

     Reply
8. Eileen says:
   August 23, 2023

   I have made this several times for work friends. Not a day goes by that someone asks for another cake!!

   ★★★★★

   Reply
9. Dawn Atkins says:
   August 20, 2023

   The best coconut cake in the history of coconut cakes! You never let me down! You are my go-to person when I need to rock the house.

   Reply
10. Susan says:
    August 19, 2023

    Best coconut cake I’ve ever eaten! What a great recipe…it was perfect in every way. Hubby loved it, too.

    ★★★★★

    Reply
11. Jed says:
    August 13, 2023

    I made this cake for my dad’s birthday. The sponge was so moist and yet light at the same time, and it had wonderful flavor with the addition of the coconut extract. In fact the members of my family who don’t like flaked coconut still ate the sponge (the blitzed coconut was small enough they didn’t mind). This one is definitely going into my rotation.

    ★★★★★

    Reply
12. Mae says:
    August 10, 2023

    Made this for my sister’s birthday a few days ago and it got rave reviews. I usually like frosting better than cake but for this I actually liked the cake better! It was very delicate and it definitely fell apart on me when I went to assemble. I did, however, 1.5 the recipe to make a 3 layer 9X13 cake. Next time I will assemble frozen cake and give it time to defrost already assembled. I’d also pulse up the coconut for the frosting much finer than I did this time. (I used a little bit of strawberry icing in the piping bag with the coconut frosting to give it a little swirl effect and just a hint of strawberry. I would do that again.) I also 1.5X the frosting and had the perfect amount. Really good cake, and not too difficult.

    ★★★★★

    Reply
13. R Huffman says:
    August 9, 2023

    Made this for my boss’ birthday since it is her favorite. It was a hit! Everyone loved it. So delicious. It is not too sweet and the texture just right. I made the mistake of grabbing my 8″ pans but just baked a little longer.

    ★★★★★

    Reply
14. Lyndi says:
    August 8, 2023

    Can this cake be used as the base in a tiered cake?

    Reply
    - Sally says:
      August 8, 2023

      Hi Lyndi, it can, but it’s quite delicate so I would definitely use cake dowels for support.

      Reply
15. Mary says:
    August 6, 2023

    I’ve made many coconut cakes in my 73 years, but this was the absolute best! Took to a group birthday gathering and one friend who doesn’t eat sweets ate a small piece and then asked for a second on! Thank you for this great recipe!

    ★★★★★

    Reply
16. Jesse says:
    August 6, 2023

    Baked this cake yesterday. Every easy, no baking skills needed. The cake turned out perfectly! The cake is very rich and filling, it could easily serve over 12 people.

    Reply
17. Gail Russell says:
    August 4, 2023

    This coconut cake is so amazing and absolutely perfect. It’s light, both in texture and flavour. Our son loves it so much, he requested it for his wedding cake, and it received great compliments from so many guests.
    I modified it for the wedding by cutting down the coconut in the cake and maintaining it in the filling.

    ★★★★★

    Reply
18. Abbe Pescatore says:
    August 3, 2023

    I have made several of your cakes that came out delicious and moist. Of recent I have had problems. Does the coconut cake rise a lot? My cake is just under 3” high though I don’t have as much frosting on it.
    I’m freezing this to take to a party and not sure if it’s cooked. The outside is very moist. I followed directions exactly. Weighing my pans doesn’t seem too help.

    Reply
    - Lexi @ Sally's Baking Recipes says:
      August 3, 2023

      Hi Abbe! We’re happy to help. Are the individual layers each less than 3 inches high? Or is the total stacked cake 3 inches high? The layers don’t have a ton of rise, but make sure your baking soda and baking powder are fresh (we find they start to lose their power after about 3 months, even if not yet technically expired). Try not to overmix the batter, as that can cause cakes to become squat and dense. This is a pretty moist cake, but you can use a toothpick inserted into the center of the cake to test for doneness. Hope the cake is a hit!

      Reply
19. Nancy F says:
    August 1, 2023

    How would you frost a Bundt cake? Do you slice it horizontally in half to have a middle layer frosting, or frost the outside layer only, or no frosting at all?

    Reply
    - Lexi @ Sally's Baking Recipes says:
      August 1, 2023

      Hi Nancy, either method would work! You can see how we frost the outside of this Easter Bundt cake to get an idea.

      Reply
20. Geri says:
    July 28, 2023

    Is it okay to use egg whites in a carton in place of fresh egg whites in recipes that call for egg whites?

    Reply
    - Michelle @ Sally's Baking Recipes says:
      July 29, 2023

      Hi Geri, yes, you can use carton egg whites. The carton should give measurements for substituting for real egg whites.

      Reply
21. Jamie Lee says:
    July 28, 2023

    The baking soda in this recipe is making the cake taste bitter. The amount of frosting is way too much and the cake ending up tasting too sweet. Maybe just not my cup of tea but the cake does turned out to be very moist and soft.

    Reply
22. Cathy says:
    July 27, 2023

    Is there a recipe that is very similar (moist) without the coconut! My husband can not eat coconut!

    Reply
    - Sally says:
      July 28, 2023

      Hi Cathy, see How to Make Coconut Cake section above the recipe. I list several other cakes that use this same base, and they do not use coconut.

      Reply
23. Carrie Lynn says:
    July 22, 2023

    This cake is moist and delicious! The coconut flavouring is perfect – makes it taste like coconut but not fake coconut. I made a 9×9 sheet cake and 8 cupcakes and found the recipe for frosting to be 3-4 times what I needed! FYI for anyone else not making a triple-decker layer cake!

    ★★★★★

    Reply
24. Dianna says:
    July 21, 2023

    I’m sorry if I just missed it but where are the measurements for each ingredient? I really want to try this coconut cake.

    Reply
    - Erin @ Sally's Baking Recipes says:
      July 21, 2023

      Hi Dianna, if you click the “Jump to Recipe” button at the top of the post, it will take you right to the ingredient list and recipe instructions. We hope you enjoy the cake!

      Reply
25. Kaia H says:
    July 17, 2023

    could i use unsweetened yogurt instead of sour cream? i really don’t feel like going to the store lol

    ★★★★★

    Reply
    - Erin @ Sally's Baking Recipes says:
      July 17, 2023

      Hi Kaia, plain Greek yogurt should work fine as a substitute for sour cream. Hope you enjoy the cake!

      Reply
    - Carrie Lynn says:
      July 22, 2023

      I used Greek yogurt and it turned out great (I sub Greek yogurt for sour cream in everything and, so far, it always works!)

      ★★★★★

      Reply

Previous 1 … 31 32 33
About The Author:

### Sally McKenney

Sally McKenney is a professional food photographer, cookbook author, and baker. Her kitchen-tested recipes and thorough step-by-step tutorials give readers the knowledge and confidence to bake from scratch. Sally has been featured on Good Morning America, HuffPost, Taste of Home, People and more.
Back-to-School Recipes

### Breakfast Egg Muffins (Frittata Muffins)

### My Favorite Banana Bread Recipe

### Healthy Apple Muffins

### Simply Sandwich Bread

### 1 Bowl Baked Oatmeal

### Iced Oatmeal Cookies

Sally's Baking Addiction